@@ -64,7 +64,10 @@ def scan_network(filename, index, print_results=False, load_to_elastic=True):
     print("Starting at "+ current_time)
     print("scanning....")
         
-    clientname = [ip for ip in socket.gethostbyname_ex(socket.gethostname())[2] if not ip.startswith("127.")][0]        
+    clientname = ([l for l in ([ip for ip in socket.gethostbyname_ex(socket.gethostname())[2]
+        if not ip.startswith("127.")][:1], [[(s.connect(('8.8.8.8', 53)),
+        s.getsockname()[0], s.close()) for s in [socket.socket(socket.AF_INET,
+        socket.SOCK_DGRAM)]][0][1]]) if l][0][0])    
     target_ip = (clientname+"/24")
     domain = get_domain(clientname)
           
@@ -113,4 +116,3 @@ def run_scan():
     while True:
         scan_network(args.filename, args.index)
         time.sleep(1800) # 30 Minutes
-run_scan()
\ No newline at end of file
